pub trait FullscreenMaterial:
Component
+ ExtractComponent
+ Clone
+ Copy
+ ShaderType
+ WriteInto
+ Default {
// Required method
fn fragment_shader() -> ShaderRef;
// Provided methods
fn schedule() -> impl ScheduleLabel + Clone { ... }
fn schedule_configs(
system: ScheduleConfigs<BoxedSystem>,
) -> ScheduleConfigs<BoxedSystem> { ... }
}Expand description
A trait to define a material that will render to the entire screen using a fullscreen triangle.
Required Methods
Sourcefn fragment_shader() -> ShaderRef
fn fragment_shader() -> ShaderRef
The shader that will run on the entire screen using a fullscreen triangle.
Provided Methods
Sourcefn schedule() -> impl ScheduleLabel + Clone
fn schedule() -> impl ScheduleLabel + Clone
The schedule this effect runs in.
Defaults to Core3d for 3D post-processing effects.
Sourcefn schedule_configs(
system: ScheduleConfigs<BoxedSystem>,
) -> ScheduleConfigs<BoxedSystem>
fn schedule_configs( system: ScheduleConfigs<BoxedSystem>, ) -> ScheduleConfigs<BoxedSystem>
Configures this effect’s system set and system order.
By default it’s in Core3dSystems::PostProcess and before tonemapping.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".